Tk::SlideShow::Dict->Get('ti')->place(897,183);
Tk::SlideShow::Dict->Get('title')->place(209,55);
Tk::SlideShow::Dict->Get('ex')->place(533,517);
Tk::SlideShow::Dict->Get('t0')->place(241,292)->fontFamily('charter')->color('purple');
Tk::SlideShow::Dict->Get('a0')->place(425,383);
Tk::SlideShow::Dict->Get('a1')->place(533,462);
Tk::SlideShow::Dict->Get('a2')->place(536,541);
