Tk::SlideShow::Dict->Get('ti')->place(924,93);
Tk::SlideShow::Dict->Get('title')->place(220,65);
Tk::SlideShow::Dict->Get('a0')->place(514,312);
Tk::SlideShow::Dict->Get('a1')->place(518,416);
Tk::SlideShow::Dict->Get('a2')->place(506,505);
Tk::SlideShow::Dict->Get('a3')->place(522,625);
