Tk::SlideShow::Dict->Get('id1')->place(171,447);
Tk::SlideShow::Dict->Get('id2')->place(629,447);
Tk::SlideShow::Dict->Get('id1-id2')->ftpos(3,7)->width(17)->shape(23,34,10);
Tk::SlideShow::Dict->Get('id3')->place(252,222);
Tk::SlideShow::Dict->Get('id4')->place(693,221);
Tk::SlideShow::Dict->Get('id3-id4')->ftpos(3,7)->width(10)->shape(22,34,13);
Tk::SlideShow::Dict->Get('id5')->place(780,493);
Tk::SlideShow::Dict->Get('id6')->place(782,678);
Tk::SlideShow::Dict->Get('id5-id6')->ftpos(5,1)->width(1)->shape(8,10,3);
Tk::SlideShow::Dict->Get('id7')->place(697,113);
Tk::SlideShow::Dict->Get('id8')->place(261,113);
Tk::SlideShow::Dict->Get('id7-id8')->ftpos(7,3)->width(1)->shape(8,10,3);
Tk::SlideShow::Dict->Get('id9')->place(249,690);
Tk::SlideShow::Dict->Get('ie0')->place(250,514);
Tk::SlideShow::Dict->Get('id9-ie0')->ftpos(1,5)->width(7)->shape(11,18,5);
Tk::SlideShow::Dict->Get('ie1')->place(796,298);
Tk::SlideShow::Dict->Get('ie2')->place(246,366);
Tk::SlideShow::Dict->Get('ie1-ie2')->ftpos(7,3)->width(15)->shape(22,60,11);
