Tk::SlideShow::Dict->Get('ti')->place(922,89);
Tk::SlideShow::Dict->Get('title')->place(241,61);
Tk::SlideShow::Dict->Get('aaa')->place(657,63);
Tk::SlideShow::Dict->Get('t1')->place(490,271);
Tk::SlideShow::Dict->Get('t2')->place(456,374);
Tk::SlideShow::Dict->Get('t3')->place(468,493);
