Tk::SlideShow::Dict->Get('i0')->place(120,581);
Tk::SlideShow::Dict->Get('i1')->place(121,407);
Tk::SlideShow::Dict->Get('i0-i1')->ftpos(1,5);
Tk::SlideShow::Dict->Get('i2')->place(225,228);
Tk::SlideShow::Dict->Get('i1-i2')->ftpos(1,6);
Tk::SlideShow::Dict->Get('i3')->place(439,97);
Tk::SlideShow::Dict->Get('i2-i3')->ftpos(1,6);
Tk::SlideShow::Dict->Get('i4')->place(737,220);
Tk::SlideShow::Dict->Get('i3-i4')->ftpos(4,1);
Tk::SlideShow::Dict->Get('i5')->place(600,428);
Tk::SlideShow::Dict->Get('i4-i5')->ftpos(5,1);
Tk::SlideShow::Dict->Get('i6')->place(520,515);
Tk::SlideShow::Dict->Get('i5-i6')->ftpos(5,1);
Tk::SlideShow::Dict->Get('i7')->place(358,556);
Tk::SlideShow::Dict->Get('i6-i7')->ftpos(7,2);
Tk::SlideShow::Dict->Get('i8')->place(257,420);
Tk::SlideShow::Dict->Get('i7-i8')->ftpos(0,5);
Tk::SlideShow::Dict->Get('i9')->place(421,245);
Tk::SlideShow::Dict->Get('i8-i9')->ftpos(1,6);
Tk::SlideShow::Dict->Get('i10')->place(536,315);
Tk::SlideShow::Dict->Get('i9-i10')->ftpos(4,0);
