Tk::SlideShow::Dict->Get('ti')->place(930,86);
Tk::SlideShow::Dict->Get('title')->place(238,57);
Tk::SlideShow::Dict->Get('aaa')->place(651,64);
Tk::SlideShow::Dict->Get('ex')->place(832,696);
Tk::SlideShow::Dict->Get('a0')->place(149,180)->color('blue');
Tk::SlideShow::Dict->Get('a1')->place(553,137);
Tk::SlideShow::Dict->Get('a2')->place(140,352);
Tk::SlideShow::Dict->Get('a3')->place(219,572);
Tk::SlideShow::Dict->Get('a4')->place(666,641);
Tk::SlideShow::Dict->Get('o0')->place(403,323)->wh(71,37);
Tk::SlideShow::Dict->Get('a0-o0')->ftpos(3,1);
Tk::SlideShow::Dict->Get('o1')->place(541,322)->wh(194,81);
Tk::SlideShow::Dict->Get('a1-o1')->ftpos(5,1);
Tk::SlideShow::Dict->Get('o2')->place(358,347)->wh(60,42);
Tk::SlideShow::Dict->Get('a2-o2')->ftpos(3,7);
Tk::SlideShow::Dict->Get('o3')->place(439,413)->wh(117,82);
Tk::SlideShow::Dict->Get('a3-o3')->ftpos(1,7);
Tk::SlideShow::Dict->Get('o4')->place(443,483)->wh(103,36);
Tk::SlideShow::Dict->Get('a4-o4')->ftpos(1,3);
