Tk::SlideShow::Dict->Get('ti')->place(912,84);
Tk::SlideShow::Dict->Get('title')->place(177,47);
Tk::SlideShow::Dict->Get('a0')->place(512,199)->color('red');
Tk::SlideShow::Dict->Get('a1')->place(504,306)->color('blue');
Tk::SlideShow::Dict->Get('a2')->place(488,420)->color('purple');
Tk::SlideShow::Dict->Get('a3')->place(483,530)->color('magenta');
